@@ -67,12 +67,12 @@ This module only supports the 'get_tax' method at the moment.
 
 =head1 VERSION
 
-Version 1.1.0
+Version 1.2.0
 
 =cut
 
-our $VERSION = '1.1.0';
-our $AVALARA_REQUEST_SERVER = 'rest.avalara.net';
+our $VERSION = '1.2.0';
+our $AVALARA_REQUEST_SERVER = 'avatax.avalara.net';
 our $AVALARA_DEVELOPMENT_REQUEST_SERVER = 'development.avalara.net';
 
 	
@@ -167,7 +167,35 @@ Makes a JSON request using the 'get_tax' method, parses the response, and return
 		commit                => 1|0, # Default 0, whether this is a 'final' query.
 		unique_key            => A unique key for memcache (optional, see below)
 		cache_timespan        => The number of seconds to cache results (see below),
-		doc_code              => Unique document code (optional),
+		currency_code         => 3 character ISO 4217 compliant currency code (optional),
+	);
+
+
+If you are issuing a refund or credit memo for part of the order (for the full order
+you may want to void the order using the C<cancel_tax()> method), you may need to specify
+the date the tax was originally calculated, and you need to specify the amounts as
+negative values.
+
+	my $tax_results = $avalara_gateway->get_tax(
+		document_type         => 'ReturnInvoice',
+		document_code         => $original_order_number (optional), or a unique identifier
+		document_date         => $date (optional), default is current date
+		tax_override          => {
+			reason            => 'Return',
+			tax_override_type => 'TaxDate',
+			tax_date          => 'YYYY-MM-DD', # Original date of the order.
+		},
+		# Just the lines being refunded.
+		cart_lines            => [
+			{
+				sku      => $sku_identifier,
+				quantity => $number_of_units_to_refund,
+				amount   => $amount_to_refund,  # Negative value.
+			},
+		],
+		discount              => $amount_to_decrease_refund (optional),  # Negative value.
+		commit                => 1|0, # Default 0, whether this is a 'final' query.
+		# Include other fields as needed.
 	);
 
 See below for the definitions of address and cart_line fields. The field origin_address
@@ -390,6 +418,7 @@ sub _generate_request_json
 		payment_date          => 'PaymentDate',
 		reference_code        => 'ReferenceCode',
 		document_code         => 'DocCode',
+		currency_code         => 'CurrencyCode',
 	);
 	
 	foreach my $node_name ( keys %optional_nodes )
@@ -398,6 +427,26 @@ sub _generate_request_json
 		$request->{ $optional_nodes{ $node_name } } = $args{ $node_name };
 	}
 	
+	my %tax_override_nodes =
+	(
+		'reason'              => 'Reason', # Typical reasons include: 'Return', 'Layaway', 'Imported'.
+		'tax_override_type'   => 'TaxOverrideType', # None, TaxAmount, Exemption, or TaxDate.
+		'tax_date'            => 'TaxDate', # Date the tax was calculated (if type is TaxDate).
+		'tax_amount'          => 'TaxAmount', # The amount of tax to apply (if type is TaxAmount).
+	);
+
+	# Fill in the TaxOverride values.
+	if ( defined $args{'tax_override'} )
+	{
+		foreach my $node ( keys %tax_override_nodes )
+		{
+			if ( defined $args{'tax_override'}{ $node } )
+			{
+				$request->{'TaxOverride'}{ $tax_override_nodes{ $node } } = $args{'tax_override'}{ $node };
+			}
+		}
+	}
+
 	my $json = JSON::PP->new()->ascii()->pretty()->allow_nonref();
 	return $json->encode( $request );
 }
@@ -553,7 +602,7 @@ sub _generate_cart_line_json
 		'ref_1'               => 'Ref1',
 		'ref_2'               => 'Ref2',
 	);
-	
+
 	foreach my $node ( keys %nodes )
 	{
 		if ( defined $cart_line->{ $node } )
@@ -561,6 +610,26 @@ sub _generate_cart_line_json
 			$cart_line_request->{ $nodes{ $node } } = $cart_line->{ $node };
 		}
 	}
+
+	my %tax_override_nodes =
+	(
+		'reason'              => 'Reason', # Typical reasons include: 'Return', 'Layaway', 'Imported'.
+		'tax_override_type'   => 'TaxOverrideType', # None, TaxAmount, Exemption, or TaxDate.
+		'tax_date'            => 'TaxDate', # Date the tax was calculated (if type is TaxDate).
+		'tax_amount'          => 'TaxAmount', # The amount of tax to apply (if type is TaxAmount).
+	);
+
+	# Fill in the TaxOverride values.
+	if ( defined $cart_line->{'tax_override'} )
+	{
+		foreach my $node ( keys %tax_override_nodes )
+		{
+			if ( defined $cart_line->{'tax_override'}{ $node } )
+			{
+				$cart_line_request->{'TaxOverride'}{ $tax_override_nodes{ $node } } = $cart_line->{'tax_override'}{ $node };
+			}
+		}
+	}
 	
 	return $cart_line_request;
 }
@@ -741,6 +810,10 @@ sub set_cache
 Kate Kirby, C<< <kate at cpan.org> >>.
 
 
+=head1 MAINTAINER
+
+Nathan Gray E<lt>kolibrie@cpan.orgE<gt>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-business-tax-avalara at rt.cpan.org>, or through
@@ -790,6 +863,8 @@ and write code for them!
 
 Copyright 2012 Kate Kirby.
 
+Copyright (C) 2017 Nathan Gray
+
 This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.
 
 This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
